#!/bin/sh
################################
#####  Persian HD Project  #####
#######  Persian Prince  #######
##  https://persianpros.com  ###
################################

LINE="---------------------------------------------"
KITDIR=/media/hdd/ipkserver
TMP=/tmp/.package
PACKAGE=$KITDIR/Packages
cd $KITDIR
if [ `ls $KITDIR/*.ipk |wc -l` -gt 0 ]; then
   echo $LINE
   echo "found *.ipk files at $KITDIR"
   echo $LINE
   echo "updating Packages file now ..."
   IPKS=`ls *.ipk`
   rm "$PACKAGE*" > /dev/null 2>&1
   for IPK in $IPKS; do
     echo $LINE
     echo Processing: $IPK ...
     tar -tjf $IPK > $TMP 2>&1
     if [ `cat $TMP | wc -l` -gt 2 ]; then
        echo Packed with tar and bzip2 ...
        tar -xjf $IPK ./control.tar.gz 
     fi
     tar -tzf $IPK > $TMP 2>&1
     if [ `cat $TMP | wc -l` -gt 2 ]; then
        echo Packed with tar and gzip ...
        tar -xzf $IPK ./control.tar.gz
        tar -xzf control.tar.gz ./control
     fi
     ar -t $IPK > $TMP 2>&1
     if [ `cat $TMP | wc -l` -gt 2 ]; then
        echo Packed with ar ...
        ar -x $IPK control.tar.gz
     fi
     tar -xzf control.tar.gz ./control
     echo "writing Package file ..."
     head -n 8 control >> $PACKAGE
     echo "Filename: $IPK" >> $PACKAGE
     SIZE=`wc -c < $IPK`
     echo "Size: $SIZE" >> $PACKAGE
     md5sum $IPK > $TMP
     sed -ie s!$IPK!""!g $TMP
     MD5=`cat $TMP`
     echo "MD5sum: $MD5" >> $PACKAGE
     tail -n 3 control >> $PACKAGE
     echo >> $PACKAGE
     echo >> $PACKAGE
     rm control.tar.gz > /dev/null 2>&1
     rm control > /dev/null 2>&1
  done
else
   echo $LINE
   echo "no *.ipk files found at$KITDIR" 
   echo $LINE
fi

if [ ! -f $PACKAGE ]; then
   touch $PACKAGE
fi
cp $PACKAGE $TMP
rm $PACKAGE.gz > /dev/null 2>&1
gzip $PACKAGE
cp $TMP $PACKAGE
rm $TMP > /dev/null 2>&1
#
# configuration housekeeping comes here
#
echo $LINE
echo "Configuration check for local ipkserver"
echo $LINE

FEED=`ls /etc/opkg/*feed*`
echo "ipk Feed for image: $FEED"
echo $LINE
if [ `cat $FEED | grep http://127.0.0.1/hdd/ipkserver | wc -l` -eq 0 ]; then
   echo "local ipkserver added to feed"
   echo "src/gz localipkserver http://127.0.0.1/hdd/ipkserver" > /etc/opkg/local-feed.conf
else
   echo "local ipkserver already included in feed"
fi
echo $LINE

if [ `cat /etc/enigma2/settings | grep config.plugins.Webinterface.includehdd=true | wc -l` -eq 0 ]; then
   echo "stopping enigma2 to make sure that /hdd is served by WebIF"
   init 4
   
   killall -9 enigma2

   grep -v config.plugins.Webinterface.includehdd /etc/enigma2/settings > $TMP
   echo "config.plugins.Webinterface.includehdd=true" >> $TMP
   cp $TMP /etc/enigma2/settings
   echo "starting enigma2 again"
   init 3
else
   echo "/hdd is already served by WebIF"
   echo $LINE
   echo "doing opkg update"
   echo $LINE
   opkg update
   echo $LINE
fi
echo "local ipkserver is updated!"
echo $LINE


exit 0

